package Mason::Plugin::HTMLStringFilters;
{
  $Mason::Plugin::HTMLStringFilters::VERSION = '0.132630';
}
use Moose;
with 'Mason::Plugin';

1;

__END__

=pod

=head1 NAME

Mason::Plugin::HTMLStringFilters - Filters related to HTML generation

=head1 VERSION

version 0.132630

=head1 FILTERS

=over

=item HTML or H

Do a basic HTML escape on the content - just the characters '&', '>', '<', and
'"'.

    <input name="company" value="<% $company | H %>">

=item HTMLEntities

Do a comprehensive HTML escape on the content, using
HTML::Entities::encode_entities.

=item URI or U

URI-escape the content.

    <a href="<% $url | U %>">

=item HTMLPara

Formats a block of text into HTML paragraphs.  A sequence of two or more
newlines is used as the delimiter for paragraphs which are then wrapped in HTML
""<p>""...""</p>"" tags. Taken from L<Template::Toolkit|Template>. e.g.

    <% $.HTMLPara { %>
    First paragraph.
      
    Second paragraph.
    </%>

outputs:

    <p>
    First paragraph.
    </p>
      
    <p>
    Second paragraph.
    </p>

=item HTMLParaBreak

Similar to HTMLPara above, but uses the HTML tag sequence "<br><br>" to join
paragraphs. Taken from L<Template::Toolkit|Template>. e.g.

    <% $.HTMLPara { %>
    First paragraph.
      
    Second paragraph.
    </%>

outputs:

    First paragraph.
    <br><br>
    Second paragraph.

=back

=head1 SEE ALSO

L<Mason|Mason>

=head1 AUTHOR

Tomohiro Hosaka <bokutin@bokut.in>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Tomohiro Hosaka.  No
license is granted to other entities.

=cut
